<p align="center">
<img src="https://image.flaticon.com/icons/svg/2948/2948063.svg" height="150" width="250" />  
</p>
<h1 align="center">CONO LIST</h1>
<h3 align="center">Surf paths easily from console</h3>
<p align="center">
  <img src="https://img.shields.io/pypi/v/conolist"/>
  <img src="https://img.shields.io/github/issues/E-RROR/conolist"/>
</p>

# Installation
```
pip3 install conolist
```

# Usage
from anywhere in your terminal just run `conolist`

# Keys and features available
| Key | Purpose|
| --- | --- |
| q | quit |
| c  | enter command |
| i  | option menu on folders |
| Key up | go up |
| Key Down  | go down |
| Enter on folder | go to that path |
| Enter on file | option menu for file |

# Example
[![asciicast](https://asciinema.org/a/345407.svg)](https://asciinema.org/a/345407)
